@@ -354,24 +354,37 @@ def pinv_extended(X, rcond=1e-15):
     return res, s_orig
 
 
-def recipr(X):
+def recipr(x):
     """
     Return the reciprocal of an array, setting all entries less than or
     equal to 0 to 0. Therefore, it presumes that X should be positive in
     general.
     """
-    x = np.maximum(np.asarray(X).astype(np.float64), 0)
-    return np.greater(x, 0.) / (x + np.less_equal(x, 0.))
+
+    x = np.asarray(x)
+    out = np.zeros_like(x, dtype=np.float64)
+    nans = np.isnan(x.flat)
+    pos = ~nans
+    pos[pos] = pos[pos] & (x.flat[pos] > 0)
+    out.flat[pos] = 1.0 / x.flat[pos]
+    out.flat[nans] = np.nan
+    return out
 
 
-def recipr0(X):
+def recipr0(x):
     """
     Return the reciprocal of an array, setting all entries equal to 0
     as 0. It does not assume that X should be positive in
     general.
     """
-    test = np.equal(np.asarray(X), 0)
-    return np.where(test, 0, 1. / X)
+    x = np.asarray(x)
+    out = np.zeros_like(x, dtype=np.float64)
+    nans = np.isnan(x.flat)
+    non_zero = ~nans
+    non_zero[non_zero] = non_zero[non_zero] & (x.flat[non_zero] != 0)
+    out.flat[non_zero] = 1.0 / x.flat[non_zero]
+    out.flat[nans] = np.nan
+    return out
 
 
 def clean0(matrix):
@@ -383,23 +396,6 @@ def clean0(matrix):
     return np.array(np.transpose(val))
 
 
-def rank(X, cond=1.0e-12):
-    """
-    Return the rank of a matrix X based on its generalized inverse,
-    not the SVD.
-    """
-    from warnings import warn
-    warn("rank is deprecated and will be removed in 0.7."
-         " Use np.linalg.matrix_rank instead.", FutureWarning)
-    X = np.asarray(X)
-    if len(X.shape) == 2:
-        D = svdvals(X)
-        return int(np.add.reduce(np.greater(D / D.max(),
-                                            cond).astype(np.int32)))
-    else:
-        return int(not np.alltrue(np.equal(X, 0.)))
-
-
 def fullrank(X, r=None):
     """
     Return a matrix whose column span is the same as X.
@@ -500,22 +496,14 @@ def maybe_unwrap_results(results):
     """
     return getattr(results, '_results', results)
 
-
 class Bunch(dict):
     """
     Returns a dict-like object with keys accessible via attribute lookup.
     """
-    def __init__(self, **kw):
-        dict.__init__(self, kw)
+    def __init__(self, *args, **kwargs):
+        super(Bunch, self).__init__(*args, **kwargs)
         self.__dict__ = self
 
-webuse = np.deprecate(webuse,
-                      old_name='statsmodels.tools.tools.webuse',
-                      new_name='statsmodels.datasets.webuse',
-                      message='webuse will be removed from the tools '
-                              'namespace in the 0.7.0 release. Please use the'
-                              ' new import.')
-
 
 def _ensure_2d(x, ndarray=False):
     """
