@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Dynamic factor model
 
@@ -10,15 +11,12 @@ from warnings import warn
 from statsmodels.compat.collections import OrderedDict
 
 import numpy as np
-import pandas as pd
-from .kalman_filter import KalmanFilter, FilterResults
 from .mlemodel import MLEModel, MLEResults, MLEResultsWrapper
 from .tools import (
-    companion_matrix, diff, is_invertible,
+    is_invertible, prepare_exog,
     constrain_stationary_univariate, unconstrain_stationary_univariate,
     constrain_stationary_multivariate, unconstrain_stationary_multivariate
 )
-from scipy.linalg import solve_discrete_lyapunov
 from statsmodels.multivariate.pca import PCA
 from statsmodels.regression.linear_model import OLS
 from statsmodels.tsa.vector_ar.var_model import VAR
@@ -138,7 +136,7 @@ class DynamicFactor(MLEModel):
 
     References
     ----------
-    .. [1] Lutkepohl, Helmut. 2007.
+    .. [*] Lütkepohl, Helmut. 2007.
        New Introduction to Multiple Time Series Analysis.
        Berlin: Springer.
 
@@ -161,20 +159,7 @@ class DynamicFactor(MLEModel):
         self.error_cov_type = error_cov_type
 
         # Exogenous data
-        self.k_exog = 0
-        if exog is not None:
-            exog_is_using_pandas = _is_using_pandas(exog, None)
-            if not exog_is_using_pandas:
-                exog = np.asarray(exog)
-
-            # Make sure we have 2-dimensional array
-            if exog.ndim == 1:
-                if not exog_is_using_pandas:
-                    exog = exog[:, None]
-                else:
-                    exog = pd.DataFrame(exog)
-
-            self.k_exog = exog.shape[1]
+        (self.k_exog, exog) = prepare_exog(exog)
 
         # Note: at some point in the future might add state regression, as in
         # SARIMAX.
@@ -401,7 +386,6 @@ class DynamicFactor(MLEModel):
 
     def _initialize_error_transition_individual(self):
         k_endog = self.k_endog
-        _factor_order = self._factor_order
         _error_order = self._error_order
 
         # Initialize the parameters
@@ -440,15 +424,9 @@ class DynamicFactor(MLEModel):
         idx = idx[:, np.lexsort((idx[1], idx[0]))]
         self._idx_error_transition = np.s_['transition', idx[0], idx[1]]
 
-    def filter(self, params, **kwargs):
-        kwargs.setdefault('results_class', DynamicFactorResults)
-        kwargs.setdefault('results_wrapper_class', DynamicFactorResultsWrapper)
-        return super(DynamicFactor, self).filter(params, **kwargs)
-
-    def smooth(self, params, **kwargs):
-        kwargs.setdefault('results_class', DynamicFactorResults)
-        kwargs.setdefault('results_wrapper_class', DynamicFactorResultsWrapper)
-        return super(DynamicFactor, self).smooth(params, **kwargs)
+    @property
+    def _res_classes(self):
+        return {'fit': (DynamicFactorResults, DynamicFactorResultsWrapper)}
 
     @property
     def start_params(self):
@@ -516,7 +494,6 @@ class DynamicFactor(MLEModel):
 
         # 4. Errors
         if self.error_order == 0:
-            error_params = []
             if self.error_cov_type == 'scalar':
                 params[self._params_error_cov] = endog.var(axis=0).mean()
             elif self.error_cov_type == 'diagonal':
@@ -689,8 +666,7 @@ class DynamicFactor(MLEModel):
             # This is always an identity matrix, but because the transform
             # done prior to update (where the ssm representation matrices
             # change), it may be complex
-            cov = self.ssm[
-                'state_cov', :self.k_factors, :self.k_factors].real
+            cov = self.ssm['state_cov', :self.k_factors, :self.k_factors].real
             coefficient_matrices, variance = (
                 constrain_stationary_multivariate(unconstrained_matrices, cov))
             constrained[self._params_factor_transition] = (
@@ -750,7 +726,7 @@ class DynamicFactor(MLEModel):
             Array of unconstrained parameters used by the optimizer.
         """
         constrained = np.array(constrained, ndmin=1)
-        dtype=constrained.dtype
+        dtype = constrained.dtype
         unconstrained = np.zeros(constrained.shape, dtype=dtype)
 
         # 1. Factor loadings
@@ -780,8 +756,7 @@ class DynamicFactor(MLEModel):
             constrained_matrices = (
                 constrained[self._params_factor_transition].reshape(
                     self.k_factors, self._factor_order))
-            cov = self.ssm[
-                'state_cov', :self.k_factors, :self.k_factors].real
+            cov = self.ssm['state_cov', :self.k_factors, :self.k_factors].real
             coefficient_matrices, variance = (
                 unconstrain_stationary_multivariate(
                     constrained_matrices, cov))
@@ -945,7 +920,7 @@ class DynamicFactorResults(MLEResults):
 
         self.specification = Bunch(**{
             # Model properties
-            'k_endog' : self.model.k_endog,
+            'k_endog': self.model.k_endog,
             'enforce_stationarity': self.model.enforce_stationarity,
 
             # Factor-related properties
@@ -996,7 +971,7 @@ class DynamicFactorResults(MLEResults):
         -------
         out: Bunch
             Has the following attributes:
-            
+
             - `filtered`: a time series array with the filtered estimate of
                           the component
             - `filtered_cov`: a time series array with the filtered estimate of
@@ -1019,7 +994,7 @@ class DynamicFactorResults(MLEResults):
                 filtered=res.filtered_state[offset:end],
                 filtered_cov=res.filtered_state_cov[offset:end, offset:end],
                 smoothed=None, smoothed_cov=None,
-                        offset=offset)
+                offset=offset)
             if self.smoothed_state is not None:
                 out.smoothed = self.smoothed_state[offset:end]
             if self.smoothed_state_cov is not None:
@@ -1119,7 +1094,7 @@ class DynamicFactorResults(MLEResults):
         for coeffs in coefficients_of_determination.T:
             # Create the new axis
             ax = fig.add_subplot(spec.k_factors, 1, plot_idx)
-            ax.set_ylim((0,1))
+            ax.set_ylim((0, 1))
             ax.set(title='Factor %i' % plot_idx, ylabel=r'$R^2$')
             bars = ax.bar(locations, coeffs)
 
@@ -1135,8 +1110,8 @@ class DynamicFactorResults(MLEResults):
 
         return fig
 
-    def get_prediction(self, start=None, end=None, dynamic=False, exog=None,
-                       **kwargs):
+    def get_prediction(self, start=None, end=None, dynamic=False, index=None,
+                       exog=None, **kwargs):
         """
         In-sample prediction and out-of-sample forecasting
 
@@ -1175,11 +1150,11 @@ class DynamicFactorResults(MLEResults):
             Array of out of sample forecasts.
         """
         if start is None:
-                start = 0
+            start = self.model._index[0]
 
         # Handle end (e.g. date)
-        _start = self.model._get_predict_start(start)
-        _end, _out_of_sample = self.model._get_predict_end(end)
+        _start, _end, _out_of_sample, prediction_index = (
+            self.model._get_prediction_index(start, end, index, silent=True))
 
         # Handle exogenous parameters
         if _out_of_sample and self.model.k_exog > 0:
@@ -1231,8 +1206,8 @@ class DynamicFactorResults(MLEResults):
                  ' required. `exog` argument ignored.', ValueWarning)
 
         return super(DynamicFactorResults, self).get_prediction(
-            start=start, end=end, dynamic=dynamic, exog=exog, **kwargs
-        )
+            start=start, end=end, dynamic=dynamic, index=index, exog=exog,
+            **kwargs)
 
     def summary(self, alpha=.05, start=None, separate_params=True):
         from statsmodels.iolib.summary import summary_params
@@ -1292,12 +1267,10 @@ class DynamicFactorResults(MLEResults):
             exog_indices = indices[self.model._params_exog]
             exog_masks = []
             for i in range(k_endog):
-                offset = 0
-
                 # 1. Factor loadings
                 # Recall these are in the form:
                 # 'loading.f1.y1', 'loading.f2.y1', 'loading.f1.y2', ...
-                
+
                 loading_mask = (
                     loading_indices[i * k_factors:(i + 1) * k_factors])
                 loading_masks.append(loading_mask)
@@ -1380,4 +1353,5 @@ class DynamicFactorResultsWrapper(MLEResultsWrapper):
     _methods = {}
     _wrap_methods = wrap.union_dicts(MLEResultsWrapper._wrap_methods,
                                      _methods)
-wrap.populate_wrapper(DynamicFactorResultsWrapper, DynamicFactorResults)
+wrap.populate_wrapper(DynamicFactorResultsWrapper,  # noqa:E305
+                      DynamicFactorResults)
